@@ -1,18 +1,17 @@
 import requests
 
-from slai.modules.parameters import from_config
-from slai.config import get_api_base_url
-from slai.modules.runtime import detect_runtime, detect_credentials
-from slai.clients.model import get_model_client
-
 from requests.auth import HTTPBasicAuth
 from importlib import import_module
+from slai.modules.parameters import from_config
+from slai.config import get_api_base_urls
+from slai.modules.runtime import detect_credentials
+from slai.clients.model import get_model_client
 
 
 REQUESTS_TIMEOUT = 15
 
 
-def get_inference_client(*, model_name, project_name, model_version_name):
+def get_inference_client(*, org_name, model_name, model_version_name):
     import_path = from_config(
         "MODEL_INFERENCE_CLIENT",
         "slai.clients.inference.ModelInferenceClient",
@@ -21,30 +20,32 @@ def get_inference_client(*, model_name, project_name, model_version_name):
     path = ".".join(import_path.split(".")[:-1])
 
     return getattr(import_module(path), class_)(
+        org_name=org_name,
         model_name=model_name,
-        project_name=project_name,
         model_version_name=model_version_name,
     )
 
 
 class ModelInferenceClient:
-    BASE_URL = get_api_base_url()
+    BACKEND_BASE_URL, MODEL_BASE_URL = get_api_base_urls()
+
+    def __init__(self, *, org_name, model_name, model_version_name=None):
+        credentials = detect_credentials()
 
-    def __init__(self, *, model_name, project_name, model_version_name=None):
-        self.runtime = detect_runtime()
-        credentials = detect_credentials(runtime=self.runtime)
         self.client_id = credentials["client_id"]
         self.client_secret = credentials["client_secret"]
 
+        self.model_server_id = None
+        self.org_name = org_name
         self.model_name = model_name
-        self.project_name = project_name
         self.model_version_name = model_version_name
 
         self._load_model()
 
     def _load_model(self):
         self.model_client = get_model_client(
-            model_name=self.model_name, project_name=self.project_name
+            org_name=self.org_name,
+            model_name=self.model_name,
         )
         self.model = self.model_client.get_model()
 
@@ -66,14 +67,22 @@ class ModelInferenceClient:
         if body.get("model_version_id") is None:
             del body["model_version_id"]
 
+        res = None
         res = requests.post(
-            f"{self.BASE_URL}/model/call",
+            f"{self.BACKEND_BASE_URL}/model/call",
             auth=HTTPBasicAuth(self.client_id, self.client_secret),
             json=body,
             timeout=REQUESTS_TIMEOUT,
         )
+
         res.raise_for_status()
-        return res.json()
+        response_data = res.json()
+
+        if response_data.get("model_server_id") is not None:
+            self.model_server_id = response_data["model_server_id"]
+            del response_data["model_server_id"]
+
+        return response_data["result"]
 
     def info(self):
         body = {
