@@ -1,7 +1,7 @@
 import boto3
 
 from slai.exceptions import InvalidAWSProfile, InvalidServicePrefix
-from botocore.exceptions import ClientError, ProfileNotFound
+from botocore.exceptions import ProfileNotFound
 
 
 class SSMClient:
